(function (Drupal, drupalSettings) {
  Drupal.overview_builder_ajax_overview =
    Drupal.overview_builder_ajax_overview || {};

  Drupal.behaviors.overview_builder_ajax_overview = {
    attach(context, settings) {
      document
        .querySelectorAll('.js-overview-builder-overview')
        .forEach((overview) => {
          if (overview.dataset.triggered) {
            return;
          }
          overview.dataset.triggered = true;
          const filters = overview.querySelector(
            '.js-overview-builder-filters',
          );
          if (filters) {
            filters.addEventListener('submit', (event) => {
              event.preventDefault();
              const formData = new FormData(filters);
              Drupal.overview_builder_ajax_overview.updateOverview(
                filters.closest('.js-overview-builder-overview'),
                formData,
              );
            });
          }
          overview
            .querySelectorAll('.js-pager__items a')
            .forEach((pagerLink) => {
              pagerLink.addEventListener('click', (event) => {
                event.preventDefault();
                const formData = new FormData();
                const urlSearchParams =
                  Drupal.overview_builder_ajax_overview.getCurrentQueryParams();
                const pagerLinkParams = new URLSearchParams(
                  pagerLink.getAttribute('href'),
                );
                urlSearchParams.set('page', pagerLinkParams.get('page'));
                urlSearchParams.forEach((value, key) => {
                  formData.append(key, value);
                });
                Drupal.overview_builder_ajax_overview.updateOverview(
                  pagerLink.closest('.js-overview-builder-overview'),
                  formData,
                );
              });
            });
        });
    },
  };

  Drupal.overview_builder_ajax_overview.updateOverview = function (
    overview,
    formData,
  ) {
    const ajax = Drupal.ajax({
      url: Drupal.overview_builder_ajax_overview.ajaxUrl(overview, formData),
      type: 'POST',
      submit: {
        path: drupalSettings.path.currentPath,
      },
      progress: {
        type: 'fullscreen',
      },
    });

    ajax.execute().done(() => {
      overview.scrollIntoView();
      Drupal.attachBehaviors();
      Drupal.overview_builder_ajax_overview.updateUrl(formData);
    });
  };

  Drupal.overview_builder_ajax_overview.ajaxUrl = function (
    overview,
    formData,
  ) {
    let url = `ajax/overview-builder/${overview.dataset.overviewId}`;
    const queryString =
      Drupal.overview_builder_ajax_overview.buildQueryString(formData);
    if (queryString) {
      url += `?${queryString}`;
    }
    return Drupal.url(url);
  };

  Drupal.overview_builder_ajax_overview.buildGetParams = function (formData) {
    const entries = formData.entries();
    return [...entries].filter(Boolean).filter((x) => {
      return x[1] && x[1] != null && x[1].length !== 0;
    });
  };

  Drupal.overview_builder_ajax_overview.updateUrl = function (formData) {
    let url = window.location.href;
    if (url.indexOf('?') !== -1) {
      url = url.split('?')[0];
    }

    if (typeof window.history.pushState === 'function') {
      const queryString =
        Drupal.overview_builder_ajax_overview.buildQueryString(formData);
      if (queryString) {
        url += `?${queryString}`;
      }
      window.history.pushState({}, 'Hide', url);
    }
  };

  Drupal.overview_builder_ajax_overview.buildQueryString = function (formData) {
    const params =
      Drupal.overview_builder_ajax_overview.buildGetParams(formData);
    return params
      .map((x) => {
        if (x[1]) {
          return `${encodeURIComponent(x[0])}=${encodeURIComponent(x[1])}`;
        }
        return null;
      })
      .join('&');
  };

  Drupal.overview_builder_ajax_overview.getCurrentQueryParams = function () {
    const url = window.location.href;
    let queryString = '';
    if (url.indexOf('?') !== -1) {
      queryString = url.split('?')[1];
    }
    return new URLSearchParams(queryString);
  };
})(Drupal, drupalSettings);
