<?php

namespace Drupal\overview_builder;

use Drupal\Component\Plugin\ConfigurableInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Plugin\PluginFormInterface;

/**
 * The Overview builder interface.
 *
 * New overview builder classes should implement this interface.
 *
 * @package Drupal\overview_builder
 */
interface OverviewBuilderInterface extends ConfigurableInterface, PluginFormInterface, ContainerFactoryPluginInterface {

  /**
   * Builds the overview.
   *
   * @return array
   *   An array containing the overview.
   */
  public function build(): array;

  /**
   * Sets a particular value in the plugin configuration.
   *
   * @param string $key
   *   The key of PluginBase::$configuration to set.
   * @param mixed $value
   *   The value to set for the provided key.
   *
   * @see \Drupal\Component\Plugin\PluginBase::$configuration
   */
  public function setConfigurationValue(string $key, $value): void;

}
