<?php

namespace Drupal\overview_builder\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Derives a views overview builder plugin for every enabled view display.
 *
 * @see \Drupal\overview_builder_example\Plugin\OverviewBuilder\ViewsOverview
 */
class ViewsOverviewDeriver extends DeriverBase implements ContainerDeriverInterface {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Builds a ViewsOverviewDeriver object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    foreach ($this->configFactory->listAll('views.view.') as $view_config_name) {
      $view = $this->configFactory->getEditable($view_config_name);

      if ($view->get('status') !== TRUE) {
        continue;
      }

      $displays = $view->get('display');

      if (!is_array($displays)) {
        continue;
      }

      foreach ($displays as $display_id => $display) {
        if (!isset($display['display_options']['display_extenders']['overview_builder']['exposed']) || $display['display_options']['display_extenders']['overview_builder']['exposed'] !== TRUE) {
          continue;
        }

        if (isset($display['display_options']['enabled']) && $display['display_options']['enabled'] === FALSE) {
          continue;
        }

        $id = $view->get('id') . '__' . $display_id;
        $admin_label = !empty($display['display_options']['display_extenders']['overview_builder']['admin_label']) ? $display['display_options']['display_extenders']['overview_builder']['admin_label'] : NULL;
        $this->derivatives[$id] = $base_plugin_definition;
        $this->derivatives[$id]['label'] = $admin_label ?? $view->get('label') . ' - ' . $display['display_title'];
        $this->derivatives[$id]['view_id'] = $view->get('id');
        $this->derivatives[$id]['display_id'] = $display_id;
        $this->derivatives[$id]['config_dependencies']['config'] = [$view_config_name];
      }
    }

    return $this->derivatives;
  }

}
