<?php

namespace Drupal\overview_builder\Plugin\views\display_extender;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\display_extender\DisplayExtenderPluginBase;

/**
 * The overview builder views display extender.
 *
 * @ingroup views_display_extender_plugins
 *
 * @ViewsDisplayExtender(
 *   id = "overview_builder",
 *   title = @Translation("Overview Builder"),
 *   help = @Translation("Expose the current display in Overview Builder"),
 *   no_ui = FALSE,
 * )
 */
class OverviewBuilder extends DisplayExtenderPluginBase {

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state): void {
    if ($form_state->get('section') !== 'overview_builder') {
      return;
    }

    $form['#title'] .= $this->t('Expose display in Overview Builder');
    $form['description'] = [
      '#markup' => '<div class="js-form-item form-item description">' . $this->t('If set, you are able to select this display in your overview builder field.') . '</div>',
    ];

    $form['exposed'] = [
      '#title' => $this->t('Expose display'),
      '#type' => 'checkbox',
      '#default_value' => $this->options['exposed'] ?? FALSE,
    ];

    $form['admin_label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Admin label'),
      '#default_value' => $this->options['admin_label'] ?? NULL,
      '#description' => $this->t('The label shown in the backend. When not filled in, the view name and display name will be shown as fallback.'),
      '#states' => [
        'visible' => [
          ':input[name="exposed"]' => ['checked' => TRUE],
        ],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function validateOptionsForm(&$form, FormStateInterface $form_state): void {
    if ($form_state->hasValue('exposed') && (bool) $form_state->getValue('exposed') !== TRUE) {
      $form_state->setValue('exposed', FALSE);
      $form_state->setValue('admin_label', NULL);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitOptionsForm(&$form, FormStateInterface $form_state): void {
    if ($form_state->get('section') !== 'overview_builder') {
      return;
    }

    $this->options['exposed'] = (bool) $form_state->getValue('exposed');
    $this->options['admin_label'] = $form_state->getValue('admin_label');
  }

  /**
   * {@inheritdoc}
   */
  public function optionsSummary(&$categories, &$options): void {
    $options['overview_builder'] = [
      'category' => 'other',
      'title' => $this->t('Expose display in Overview Builder'),
      'value' => isset($this->options['exposed']) && $this->options['exposed'] === TRUE ? $this->t('Yes') : $this->t('No'),
    ];
  }

}
