<?php

namespace Drupal\overview_builder_test\Plugin\OverviewBuilder;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\overview_builder\CustomOverviewBuilderBase;

/**
 * Configurable news overview builder.
 *
 * @OverviewBuilder(
 *   id = "configurable_news_overview",
 *   label = @Translation("Configurable news overview"),
 *   entity_type = "node",
 *   bundle = "news",
 *   view_mode = "teaser",
 * )
 */
class ConfigurableNewsOverview extends CustomOverviewBuilderBase {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'limit' => 10,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildConfigurationForm($form, $form_state);
    $form['limit'] = [
      '#type' => 'number',
      '#title' => $this->t('Limit'),
      '#default_value' => $this->configuration['limit'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state): void {
    parent::validateConfigurationForm($form, $form_state);

    if ($form_state->getValue('limit') > 100) {
      $form_state->setErrorByName('limit', $this->t('Limit should not exceed 100.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['limit'] = $form_state->getValue('limit');
  }

  /**
   * {@inheritdoc}
   */
  public function getListEntities(): array {
    $query = $this->entityStorage->getQuery();

    $query->condition('type', 'news');
    $query->addTag('node_access');
    $query->accessCheck();
    $query->pager($this->configuration['limit']);

    $results = $query->execute();
    if (empty($results)) {
      return [];
    }

    return $this->entityStorage->loadMultiple($results);
  }

}
