<?php

namespace Drupal\overview_builder_test\Plugin\OverviewBuilder;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\overview_builder\ViewsOverviewBuilderBase;

/**
 * Simple custom node overview builder.
 *
 * @OverviewBuilder(
 *   id = "configurable_news_views_overview",
 *   label = @Translation("Configurable news views overview"),
 *   view_id = "news",
 *   display_id = "block_1",
 * )
 */
class ConfigurableNewsViewsOverview extends ViewsOverviewBuilderBase {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'test_plugin_config' => 'test',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildConfigurationForm($form, $form_state);
    $form['test_plugin_config'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Test plugin config'),
      '#default_value' => $this->configuration['test_plugin_config'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state): void {
    parent::validateConfigurationForm($form, $form_state);

    if ($form_state->getValue('test_plugin_config') !== 'fail') {
      $form_state->setErrorByName('test_plugin_config', $this->t('Value should not be fail.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['test_plugin_config'] = $form_state->getValue('test_plugin_config');
  }

}
