<?php

namespace Drupal\Tests\overview_builder\FunctionalJavascript;

use Drupal\FunctionalJavascriptTests\WebDriverTestBase;

/**
 * Test the custom overview builder with AJAX enabled.
 *
 * @group overview_builder
 */
class OverviewBuilderPluginConfigurationTest extends WebDriverTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['overview_builder_paragraphs_test', 'field_ui'];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->drupalLogin($this->rootUser);

    for ($i = 1; $i <= 10; $i++) {
      $this->drupalCreateNode([
        'type' => 'news',
        'title' => $this->randomMachineName(),
      ]);
    }

  }

  /**
   * Test a configurable custom overview.
   */
  public function testConfigurableCustomOverview() {
    $this->drupalGet('/node/add/overview_page');

    $assert_session = $this->assertSession();
    $page = $this->getSession()->getPage();

    $title = $this->randomMachineName();
    $page->findField('title[0][value]')->setValue($title);

    $page->findButton('field_paragraphs_add_more')->press();
    $plugin_id_field = $assert_session->waitForElementVisible('css', '[name="field_paragraphs[0][subform][field_overview][0][plugin_id]"]');
    $plugin_id_field->selectOption('configurable_news_overview');

    $limit_field = $assert_session->waitForField('field_paragraphs[0][subform][field_overview][0][configuration][limit]');
    $limit_field->setValue(999);
    $page->pressButton('Save');
    $assert_session->responseContains('Limit should not exceed 100.');

    $limit_field->setValue(5);
    $page->pressButton('Save');

    // Check that configuration is used in build.
    $this->assertSession()->elementsCount('css', '.js-overview-builder-overview > div > ul > li', 5);

    // Check that settings are saved.
    $node = $this->drupalGetNodeByTitle($title);
    $overview_paragraph = $node->get('field_paragraphs')->entity;

    $this->assertEquals('configurable_news_overview', $overview_paragraph->get('field_overview')->plugin_id);
    $this->assertEquals(5, $overview_paragraph->get('field_overview')->configuration['limit']);

    $this->drupalGet($node->toUrl('edit-form'));
    $limit_field = $assert_session->fieldExists('field_paragraphs[0][subform][field_overview][0][configuration][limit]');
    $limit_field->setValue(10);
    $page->pressButton('Save');

    $this->assertSession()->elementsCount('css', '.js-overview-builder-overview > div > ul > li', 10);

    $this->container->get('entity_type.manager')->getStorage('paragraph')->resetCache();
    $node = $this->drupalGetNodeByTitle($title, TRUE);
    $overview_paragraph = $node->get('field_paragraphs')->entity;

    $this->assertEquals('configurable_news_overview', $overview_paragraph->get('field_overview')->plugin_id);
    $this->assertEquals(10, $overview_paragraph->get('field_overview')->configuration['limit']);
  }

}
