<?php

namespace Drupal\Tests\overview_builder\Kernel;

use Drupal\Core\Cache\Cache;
use Drupal\KernelTests\KernelTestBase;

/**
 * Test the custom overview builder plugin methods.
 *
 * @group overview_builder
 *
 * @coversDefaultClass \Drupal\overview_builder\CustomOverviewBuilderBase
 */
class OverviewBuilderCustomOverviewPluginTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'field',
    'node',
    'user',
    'system',
    'taxonomy',
    'text',
    'views',
    'pluginreference',
    'overview_builder',
    'overview_builder_test',
  ];

  /**
   * A custom overview plugin.
   *
   * @var Drupal\overview_builder\CustomOverviewBuilderBase
   */
  protected $plugin;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->installEntitySchema('user');
    $this->installEntitySchema('node');
    $this->installEntitySchema('taxonomy_term');
    $this->installConfig([
      'field',
      'pluginreference',
      'overview_builder',
      'overview_builder_test',
    ]);
    $this->plugin = $this->container->get('plugin.manager.overview_builder')->createInstance('configurable_news_overview');
  }

  /**
   * Test the getConfiguration method.
   *
   * @covers ::getConfiguration
   */
  public function testGetConfiguration() {
    $this->assertEquals(['limit' => 10], $this->plugin->getConfiguration());
    $this->plugin->setConfiguration(['limit' => 9]);
    $this->assertEquals(['limit' => 9], $this->plugin->getConfiguration());
  }

  /**
   * Test the setConfiguration method.
   *
   * @covers ::setConfiguration
   */
  public function testSetConfiguration() {
    $this->plugin->setConfiguration([]);
    $this->assertEquals(['limit' => 10], $this->plugin->getConfiguration());

    $this->plugin->setConfiguration(['limit' => 999]);
    $this->assertEquals(['limit' => 999], $this->plugin->getConfiguration());
  }

  /**
   * Test the defaultConfiguration method.
   *
   * @covers ::defaultConfiguration
   */
  public function testDefaultConfiguration() {
    $this->assertEquals(['limit' => 10], $this->plugin->defaultConfiguration());
  }

  /**
   * Test the setConfigurationValue method.
   *
   * @covers ::setConfigurationValue
   */
  public function testSetConfigurationValue() {
    $this->plugin->setConfigurationValue('limit', 999);
    $this->assertEquals(['limit' => 999], $this->plugin->getConfiguration());
  }

  /**
   * Test the getCacheContexts method.
   *
   * @covers ::getCacheContexts
   */
  public function testGetCacheContexts() {
    $this->assertEquals([
      'url.query_args',
      'languages',
    ], $this->plugin->getCacheContexts());
  }

  /**
   * Test the getCacheMaxAge method.
   *
   * @covers ::getCacheMaxAge
   */
  public function testGetCacheMaxAge() {
    $this->assertEquals(Cache::PERMANENT, $this->plugin->getCacheMaxAge());
  }

  /**
   * Test the getCacheTags method.
   *
   * @covers ::getCacheTags
   */
  public function testGetCacheTags() {
    $this->assertEquals(['node_list:news'], $this->plugin->getCacheTags());
  }

}
