<?php

namespace Drupal\Tests\overview_builder\Kernel;

use Drupal\KernelTests\KernelTestBase;

/**
 * Test the views overview builder plugin methods.
 *
 * @group overview_builder
 *
 * @coversDefaultClass \Drupal\overview_builder\ViewsOverviewBuilderBase
 */
class OverviewBuilderViewsPluginTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'field',
    'node',
    'user',
    'system',
    'taxonomy',
    'text',
    'views',
    'pluginreference',
    'overview_builder',
    'overview_builder_test',
  ];

  /**
   * A custom overview plugin.
   *
   * @var Drupal\overview_builder\CustomOverviewBuilderBase
   */
  protected $plugin;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->installEntitySchema('user');
    $this->installEntitySchema('node');
    $this->installEntitySchema('taxonomy_term');
    $this->installConfig([
      'field',
      'pluginreference',
      'overview_builder',
      'overview_builder_test',
    ]);
    $this->plugin = $this->container->get('plugin.manager.overview_builder')->createInstance('configurable_news_views_overview');
  }

  /**
   * Test the getConfiguration method.
   *
   * @covers ::getConfiguration
   */
  public function testGetConfiguration() {
    $this->assertEquals(['test_plugin_config' => 'test'], $this->plugin->getConfiguration());
    $this->plugin->setConfiguration(['test_plugin_config' => 'test2']);
    $this->assertEquals(['test_plugin_config' => 'test2'], $this->plugin->getConfiguration());
  }

  /**
   * Test the setConfiguration method.
   *
   * @covers ::setConfiguration
   */
  public function testSetConfiguration() {
    $this->plugin->setConfiguration([]);
    $this->assertEquals(['test_plugin_config' => 'test'], $this->plugin->getConfiguration());

    $this->plugin->setConfiguration(['test_plugin_config' => 'test2']);
    $this->assertEquals(['test_plugin_config' => 'test2'], $this->plugin->getConfiguration());
  }

  /**
   * Test the defaultConfiguration method.
   *
   * @covers ::defaultConfiguration
   */
  public function testDefaultConfiguration() {
    $this->assertEquals(['test_plugin_config' => 'test'], $this->plugin->defaultConfiguration());
  }

  /**
   * Test the setConfigurationValue method.
   *
   * @covers ::setConfigurationValue
   */
  public function testSetConfigurationValue() {
    $this->plugin->setConfigurationValue('test_plugin_config', 'test2');
    $this->assertEquals(['test_plugin_config' => 'test2'], $this->plugin->getConfiguration());
  }

}
